/**
 * This file is part of spy4js which is released under MIT license.
 *
 * The LICENSE file can be found in the root directory of this project.
 *
 */
import { COMPARE, MAPPER, type OptionalMessageOrError, type MessageOrError } from './utils';
import { type Mockable } from './mock';
import { Symbols } from './symbols';
export declare type GeneralSpyConfig = {
    useOwnEquals: boolean;
    enforceOrder: boolean;
    useGenericReactMocks: boolean;
};
export declare type SpyConfig = {
    useOwnEquals: boolean;
    persistent: boolean;
};
export declare type SpyInstance = {
    (...args: any[]): any;
    configure: (config: Partial<SpyConfig>) => SpyInstance;
    calls: (...funcs: Function[]) => SpyInstance;
    returns: (...args: any[]) => SpyInstance;
    resolves: (...args: any[]) => SpyInstance;
    rejects: (...msgOrErrors: OptionalMessageOrError[]) => SpyInstance;
    throws: (msgOrError?: MessageOrError) => SpyInstance;
    reset: () => SpyInstance;
    restore: () => SpyInstance;
    transparent: () => SpyInstance;
    transparentAfter: (callCount: number) => SpyInstance;
    addSnapshotSerializer: (serialize: string | ((...args: any[]) => string)) => SpyInstance;
    wasCalled: (callCount?: number) => void;
    hasCallHistory: (...callHistory: Array<any[] | any>) => void;
    wasNotCalled: () => void;
    wasCalledWith: (...args: any[]) => void;
    wasNotCalledWith: (...args: any[]) => void;
    getAllCallArguments: () => Array<any[]>;
    getCallArguments: (callNr?: number) => any[];
    getCallArgument: (callNr?: number, argNr?: number) => any;
    getLatestCallArgument: (argNr?: number) => any;
    getProps: () => any;
    hasProps: (props: any) => void;
    getCallCount: () => number;
    showCallArguments: (additionalInformation?: (string | undefined)[]) => string;
    [Symbols.name]: string;
    [Symbols.snap]: string;
    [Symbols.snapSerializer]?: (...args: any[]) => string;
    [Symbols.calls]: {
        args: any[];
        order: number;
    }[];
    [Symbols.index]: number;
    [Symbols.isSpy]: boolean;
    [Symbols.func]: Function;
    [Symbols.config]: SpyConfig;
    [Symbols.onRestore]?: () => void;
};
declare type ISpy = {
    (name?: string): SpyInstance;
    configure(config: Partial<GeneralSpyConfig> & {
        afterEach?: (scope: string) => void;
        beforeEach?: (scope: string) => void;
    }): void;
    IGNORE: Symbol;
    COMPARE: typeof COMPARE;
    MAPPER: typeof MAPPER;
    on<T extends Mockable, K extends keyof T>(obj: T, methodName: K): SpyInstance;
    mock<T extends Mockable, K extends keyof T>(obj: T, ...methodNames: K[]): {
        [P in K]: SpyInstance;
    };
    mockModule<K extends string>(moduleName: string, ...methodNames: K[]): {
        [P in K]: SpyInstance;
    };
    mockReactComponents<K extends string>(moduleName: string, ...methodNames: K[]): {
        [P in K]: SpyInstance;
    };
    initMocks(scope?: string): void;
    restoreAll(): void;
    resetAll(): void;
};
/**
 * This constructor does instantiate a Spy
 * object.
 *
 * This spy is callable.
 * It does inherit all Spy specific methods below.
 * It holds additional (private) fields:
 * _name:string -> Will be displayed in all displayed
 *                 error messages.
 * _isSpy:boolean -> Always true for spies.
 * _func:Function -> The internal function, that will
 *                   actually we called, when calling
 *                   the spy.
 * _calls:Array<{arguments:Array<any>}>
 *     -> Stores the arguments with whom the spy was called.
 *        Each call adds another entry in the calls array.
 * _config = {useOwnEquals: boolean} -> internal spy config.
 *
 *
 * @param {string} name -> the identifier of the spy.
 *                       Useful for debugging issues.
 */
declare const Spy: ISpy;
export { Spy };
